
MAX_WORDS_IN_SENTENCE = 20

MAX_SENTENCES_IN_PARAGRAPH = 6

WORDS_ONE_READS_PER_MINUTE = 200

VAGUE_WORDS = [
    "approach", "approaches", 'assumption', "assumptions", 'concept', "concepts", 'condition',
    "conditions", 'context', 'contexts', 'framework', 'frameworks', 'issue', 'issues', 'process',
    'processes', 'range', 'role', 'roles', 'strategy', 'strategies', 'tendency', 'tendencies',
    'variable', 'variables', 'perspective', 'perspectives',  'accrual', 'derivative', 'derivatives',
    'fair value', 'portfolio', 'portfolios', 'audit', 'poverty', 'evaluation', 'evaluations', 'management',
    'monitoring', 'effectiveness', 'performance', 'competitiveness', 'reform', 'assistance', 'growth',
    'effort', 'capacity', 'transparency', 'effectiveness', 'progress', 'stability', 'protection', 'access',
    'implementation', 'sustainable', 'stuff', 'really', 'etc', 'many', 'usually',
    'most', 'somehow', 'somewhat', 'somewhat like', 'soon', 'a few'

]

INTENSIFIERS = ['very', 'highly', 'extremely']

COMPULSIVE_HEDGERS = [
    'apparently', 'almost', 'fairly', 'nearly', 'partially', 'predominantly', 'presumably', 'rather', 'relative',
    'seemingly', 'sort of', 'kind of', 'a bit', 'a little', 'maybe', 'some', 'partly', 'perhaps', 'any', 'probably',
    'a touch', 'sometimes', 'mostly', 'possibly', 'might', 'a tad', 'hardly', 'seem'
]



